@@ -1,16 +1,19 @@
 package Weed::RegularExpressions;
-use Weed::Perl;
-
-our $VERSION = '0.012';
+use strict;
+use warnings;
 
 use Weed::Symbols;
 
 use base 'Exporter';
 
 our @EXPORT = qw(
+  $_X3D
+
+  $_break
   $_header
   $_whitespace
   $_comment
+  $_space_break_space
 
   $_COMPONENT
   $_DEF
@@ -38,13 +41,15 @@ our @EXPORT = qw(
   $_exposedField
   $_field
 
+  $_period
   $_open_brace
   $_close_brace
   $_close_brace_test
   $_open_bracket
   $_close_bracket
   $_brackets
-  $_period
+  $_colon
+  $_colon_test
 
   $_Id
   $_double
@@ -56,33 +61,31 @@ our @EXPORT = qw(
   $_nan
   $_inf
 
+  $_Body
+
   $_NodeTypeId
   $_ScriptNodeInterface_IS
 
   $_CosmoWorlds
   $_enum
 
-  $_RestrictedId
-  $_colon
-  $_colon_test
-  $_open_parenthesis
-  $_close_parenthesis
-
-  $_ConceptBody
-
-  $_in
-  $_out
-
-  $_FieldRange
-
+  $_FieldDescription
 );
+#$Id
+
+#$hex
+#$float
+#$int32
+#$double
+
+our $_X3D = qr.^(?!Weed::|main).so;
 
 # General
 our $space      = "[\x20\t]";
 our $break      = "[\n\r]";
 our $header     = "#VRML V2.0 (utf8)([\x20\t]+(.*?)){0,1}[\n\r]";
 our $whitespace = '[\x20\n,\t\r]';
-our $comment    = '\x23(.*?)(?:[\n\r]|$)';
+our $comment    = '#(.*?)\n';
 
 # Field Values Symbols
 our $hex    = '0[xX][\da-fA-F]+';
@@ -102,25 +105,25 @@ our $vrmlScriptFieldType  = join '|', @VrmlScriptFieldTypes;
 our $fieldType            = join '|', @FieldTypes;
 
 # Terminal symbols
+our $period        = '\\' . $_period_;
 our $open_brace    = '\\' . $_open_brace_;
 our $close_brace   = '\\' . $_close_brace_;
 our $open_bracket  = '\\' . $_open_bracket_;
 our $close_bracket = '\\' . $_close_bracket_;
-our $period        = '\\' . $_period_;
+our $colon         = '\\' . $_colon_;
 
-#
 # Other Symbols
 our $IdFirstChar = '[^\x30-\x39\x00-\x20\x22\x23\x27\x2b\x2c\x2d\x2e\x5b\x5c\x5d\x7b\x7d\x7f]{1}';
 our $IdRestChars = '[^\x00-\x20\x22\x23\x27\x2c\x2e\x5b\x5c\x5d\x7b\x7d\x7f]';
 our $Id          = "$IdFirstChar$IdRestChars*";
 
 # General
-our $_header = qr.\A$header.so;
-#our $_break      = qr.$break.so;
-our $_whitespace = qr.\G$whitespace*.so;
+our $_break      = qr.$break.so;
+our $_header     = qr.\A$header.so;
 our $_comment    = qr.\G$whitespace*$comment.so;
+our $_whitespace = qr.$whitespace.so;
 
-# concept
+our $_space_break_space = qr.$space*$break$space*.so;
 
 # VRML lexical elements
 # Keywords
@@ -149,13 +152,15 @@ our $_exposedField   = qr.\G$whitespace*$_exposedField_$whitespace+.so;
 our $_field          = qr.\G$whitespace*$_field_$whitespace+.so;
 
 # Terminal symbols
+our $_period           = qr.\G$period.so;
 our $_open_brace       = qr.\G$whitespace*$open_brace.so;
 our $_close_brace      = qr.\G$whitespace*$close_brace.so;
 our $_close_brace_test = qr.\G(?=$whitespace*$close_brace).so;
 our $_open_bracket     = qr.\G$whitespace*$open_bracket.so;
 our $_close_bracket    = qr.\G$whitespace*$close_bracket.so;
-our $_period           = qr.\G$period.so;
 our $_brackets         = qr.\G$whitespace*$open_bracket$whitespace*$close_bracket.so;    # []
+our $_colon            = qr.\G$whitespace*$colon.so;
+our $_colon_test       = qr.\G$whitespace+$colon$whitespace+.so;
 
 # Other Symbols
 our $_Id        = qr.\G$whitespace*($Id).so;
@@ -165,6 +170,8 @@ our $_float     = qr.\G$whitespace*($float).so;
 our $_int32     = qr.\G$whitespace*($int32).so;
 our $_string    = qr.\G$whitespace*"($string?)(?<!\\)".so;
 
+our $_Body = qr.\G$whitespace*($string?)$whitespace*(?=$close_brace).so;
+
 our $_NodeTypeId = qr.\G$whitespace*($Id)(?=$whitespace*$open_brace).so;
 our $_ScriptNodeInterface_IS = qr.\G$whitespace*($_eventIn_|$_eventOut_|$_field_)$whitespace+($fieldType)$whitespace+($Id)$whitespace+$_IS_.so;
 
@@ -177,33 +184,12 @@ our $_enum        = qr.\G$whitespace*($enum).so;
 our $_nan = qr.\G$whitespace*($_nan_).so;
 our $_inf = qr.\G$whitespace*($_inf_).so;
 
-#Concept
-our $open_parenthesis  = '\\' . $_open_parenthesis_;
-our $close_parenthesis = '\\' . $_close_parenthesis_;
-our $colon             = '\\' . $_colon_;
-#our $swung_dash        = '\\' . $_swung_dash_;
-
-our $RestrictedIdFirstChar = '[^\x30-\x39\x00-\x23\x27\x2b\x2c\x2d\x2e\x5b\x5c\x5d\x7b\x7d-\x7f()]{1}';
-our $RestrictedId          = "$RestrictedIdFirstChar$IdRestChars*";
-our $_space_break_space    = qr.$space*$break$space*.so;
-
-our $_RestrictedId = qr.\G$whitespace*($RestrictedId).so;
-our $_in           = qr.\G$whitespace*$_in_.so;
-our $_out          = qr.\G$whitespace*$_out_.so;
-
-#our $FieldName  = "[a-z]{1}[a-zA-Z_]*";
-#our $_FieldName = qr.\G($FieldName).so;
-
-our $_colon             = qr.\G$whitespace*$colon.so;
-our $_colon_test        = qr.\G$whitespace+$colon$whitespace+.so;
-our $_open_parenthesis  = qr.\G$whitespace*$open_parenthesis.so;
-our $_close_parenthesis = qr.\G$whitespace*$close_parenthesis.so;
-our $_ConceptBody       = qr.\G$whitespace*($string?)$whitespace*(?=$close_brace$whitespace*$).so;
+# Field type
 
 our $in  = "(?:in)";
 our $out = "(?:out)";
 
-our $_FieldRange = qr.\G$space*($string?)$space*($break+|$).so;
+our $_FieldDescription = qr.^\G$whitespace*($Id)$whitespace*$open_bracket($in?)$whitespace*($out?)$close_bracket$whitespace*($Id)$whitespace+($string).so;
 
 1;
 __END__
